@@ -10,6 +10,7 @@
 # ---------------------------------------------------------------------------------------------------------
 """
 from mysql.connector import connect
+from middleware_helper.libs import logger
 from mysql.connector.cursor_cext import CMySQLCursor
 from middleware_helper.network import filter_system_port_list
 
@@ -17,17 +18,46 @@ from middleware_helper.network import filter_system_port_list
 class Mysql(object):
 
     def __init__(self, **mysql_params_map):
-        port = mysql_params_map.get("port")
-        if isinstance(port, list):
-            mysql_params_map["port"] = filter_system_port_list(data_port=port, default_port=3306)
-        self.conn = connect(
-            host=mysql_params_map.get("host"),
-            user=mysql_params_map.get("user"),
-            port=mysql_params_map.get("port"),
-            charset=mysql_params_map.get("charset"),
-            password=mysql_params_map.get("password"),
-            database=mysql_params_map.get("database")
-        )
+        self.host = mysql_params_map.get('host') or '127.0.0.1'
+        self.port = mysql_params_map.get("port") or '3306'
+        self.user = mysql_params_map.get("user") or 'root'
+        self.password = mysql_params_map.get("password") or 'Admin@123'
+        self.database = mysql_params_map.get("database") or 'mysql'
+        self.charset = mysql_params_map.get("charset") or 'utf8'
+        self.conn = self.retry_connection()
+
+    def __connect_to_mysql(self) -> connect:
+        try:
+            if isinstance(self.port, list):
+                __port = filter_system_port_list(data_port=self.port, default_port=3306)
+            else:
+                __port = self.port
+            # 建立连接
+            conn = connect(
+                host=self.host,
+                user=self.user,
+                port=__port,
+                charset=self.charset,
+                password=self.password,
+                database=self.database
+            )
+            return conn
+        except Exception as e:
+            logger.error("数据库连接失败: {}".format(e))
+            return None
+
+    def retry_connection(self) -> connect:
+        conn = self.__connect_to_mysql()
+        i = 0
+        while conn is None or not conn.is_connected():
+            if i > 9:
+                logger.warning("尝试连接数据库10次以上，最终未能成功")
+            else:
+                if i > 0:
+                    logger.warning("尝试重连数据库...")
+                conn = self.__connect_to_mysql()
+            i = i + 1
+        return conn
 
     @classmethod
     def convert_tuple_to_dict(cls, records: list, column_names: tuple) -> list:
@@ -54,27 +84,27 @@ class Mysql(object):
 
     def execute_sql(self, sql: str, action: str):
         results = None
-        if self.conn.is_connected():
+        if self.conn and self.conn.is_connected():
             cursor: CMySQLCursor = self.conn.cursor()
             if action in ("insert", "update", "delete"):
                 try:
                     cursor.execute(sql)
                     self.conn.commit()
                 except Exception as e:
-                    print(e)
+                    logger.error(e)
                     self.conn.rollback()
             elif action == "select":
                 try:
                     # 获取查询结果
                     results = self.cursor_query_data(sql=sql, cursor=cursor)
                 except Exception as e:
-                    print(e)
+                    logger.error(e)
             else:
                 pass
             cursor.close()
             self.conn.close()
         else:
-            print("当前连接不正常.")
+            logger.error("当前连接不正常.")
         return results
 
     @classmethod
